from . import surfacemeshing

def find_triangle_geom_centroids(data_container_array, feature_attribute_matrix_name = None, face_labels_array_path = None, centroids_array_name = None, observer = None) -> int:
  """Pythonic interface to FindTriangleGeomCentroids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_attribute_matrix_name (DataArrayPath): Sets the "FeatureAttributeMatrixName" filter property
    face_labels_array_path (DataArrayPath): Sets the "FaceLabelsArrayPath" filter property
    centroids_array_name (QString): Sets the "CentroidsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.FindTriangleGeomCentroids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if face_labels_array_path is not None:
    filter.FaceLabelsArrayPath = face_labels_array_path
  if centroids_array_name is not None:
    filter.CentroidsArrayName = centroids_array_name
  filter.execute()
  return filter.ErrorCode

def find_triangle_geom_neighbors(data_container_array, feature_attribute_matrix_path = None, neighbor_list_array_name = None, face_labels_array_path = None, num_neighbors_array_name = None, observer = None) -> int:
  """Pythonic interface to FindTriangleGeomNeighbors Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_attribute_matrix_path (DataArrayPath): Sets the "FeatureAttributeMatrixPath" filter property
    neighbor_list_array_name (QString): Sets the "NeighborListArrayName" filter property
    face_labels_array_path (DataArrayPath): Sets the "FaceLabelsArrayPath" filter property
    num_neighbors_array_name (QString): Sets the "NumNeighborsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.FindTriangleGeomNeighbors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_attribute_matrix_path is not None:
    filter.FeatureAttributeMatrixPath = feature_attribute_matrix_path
  if neighbor_list_array_name is not None:
    filter.NeighborListArrayName = neighbor_list_array_name
  if face_labels_array_path is not None:
    filter.FaceLabelsArrayPath = face_labels_array_path
  if num_neighbors_array_name is not None:
    filter.NumNeighborsArrayName = num_neighbors_array_name
  filter.execute()
  return filter.ErrorCode

def find_triangle_geom_shapes(data_container_array, feature_attribute_matrix_name = None, face_labels_array_path = None, centroids_array_path = None, volumes_array_path = None, omega3s_array_name = None, axis_lengths_array_name = None, axis_euler_angles_array_name = None, aspect_ratios_array_name = None, observer = None) -> int:
  """Pythonic interface to FindTriangleGeomShapes Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_attribute_matrix_name (DataArrayPath): Sets the "FeatureAttributeMatrixName" filter property
    face_labels_array_path (DataArrayPath): Sets the "FaceLabelsArrayPath" filter property
    centroids_array_path (DataArrayPath): Sets the "CentroidsArrayPath" filter property
    volumes_array_path (DataArrayPath): Sets the "VolumesArrayPath" filter property
    omega3s_array_name (QString): Sets the "Omega3sArrayName" filter property
    axis_lengths_array_name (QString): Sets the "AxisLengthsArrayName" filter property
    axis_euler_angles_array_name (QString): Sets the "AxisEulerAnglesArrayName" filter property
    aspect_ratios_array_name (QString): Sets the "AspectRatiosArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.FindTriangleGeomShapes()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if face_labels_array_path is not None:
    filter.FaceLabelsArrayPath = face_labels_array_path
  if centroids_array_path is not None:
    filter.CentroidsArrayPath = centroids_array_path
  if volumes_array_path is not None:
    filter.VolumesArrayPath = volumes_array_path
  if omega3s_array_name is not None:
    filter.Omega3sArrayName = omega3s_array_name
  if axis_lengths_array_name is not None:
    filter.AxisLengthsArrayName = axis_lengths_array_name
  if axis_euler_angles_array_name is not None:
    filter.AxisEulerAnglesArrayName = axis_euler_angles_array_name
  if aspect_ratios_array_name is not None:
    filter.AspectRatiosArrayName = aspect_ratios_array_name
  filter.execute()
  return filter.ErrorCode

def find_triangle_geom_sizes(data_container_array, face_labels_array_path = None, feature_attribute_matrix_name = None, volumes_array_name = None, observer = None) -> int:
  """Pythonic interface to FindTriangleGeomSizes Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    face_labels_array_path (DataArrayPath): Sets the "FaceLabelsArrayPath" filter property
    feature_attribute_matrix_name (DataArrayPath): Sets the "FeatureAttributeMatrixName" filter property
    volumes_array_name (QString): Sets the "VolumesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.FindTriangleGeomSizes()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if face_labels_array_path is not None:
    filter.FaceLabelsArrayPath = face_labels_array_path
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if volumes_array_name is not None:
    filter.VolumesArrayName = volumes_array_name
  filter.execute()
  return filter.ErrorCode

def laplacian_smoothing(data_container_array, surface_data_container_name = None, surface_mesh_node_type_array_path = None, surface_mesh_face_labels_array_path = None, iteration_steps = None, lambda_value = None, surface_point_lambda = None, triple_line_lambda = None, quad_point_lambda = None, surface_triple_line_lambda = None, surface_quad_point_lambda = None, use_taubin_smoothing = None, mu_factor = None, observer = None) -> int:
  """Pythonic interface to LaplacianSmoothing Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_data_container_name (DataArrayPath): Sets the "SurfaceDataContainerName" filter property
    surface_mesh_node_type_array_path (DataArrayPath): Sets the "SurfaceMeshNodeTypeArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    iteration_steps (int): Sets the "IterationSteps" filter property
    lambda_value (float): Sets the "Lambda" filter property
    surface_point_lambda (float): Sets the "SurfacePointLambda" filter property
    triple_line_lambda (float): Sets the "TripleLineLambda" filter property
    quad_point_lambda (float): Sets the "QuadPointLambda" filter property
    surface_triple_line_lambda (float): Sets the "SurfaceTripleLineLambda" filter property
    surface_quad_point_lambda (float): Sets the "SurfaceQuadPointLambda" filter property
    use_taubin_smoothing (bool): Sets the "UseTaubinSmoothing" filter property
    mu_factor (float): Sets the "MuFactor" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.LaplacianSmoothing()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_data_container_name is not None:
    filter.SurfaceDataContainerName = surface_data_container_name
  if surface_mesh_node_type_array_path is not None:
    filter.SurfaceMeshNodeTypeArrayPath = surface_mesh_node_type_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if iteration_steps is not None:
    filter.IterationSteps = iteration_steps
  if lambda_value is not None:
    filter.Lambda = lambda_value
  if surface_point_lambda is not None:
    filter.SurfacePointLambda = surface_point_lambda
  if triple_line_lambda is not None:
    filter.TripleLineLambda = triple_line_lambda
  if quad_point_lambda is not None:
    filter.QuadPointLambda = quad_point_lambda
  if surface_triple_line_lambda is not None:
    filter.SurfaceTripleLineLambda = surface_triple_line_lambda
  if surface_quad_point_lambda is not None:
    filter.SurfaceQuadPointLambda = surface_quad_point_lambda
  if use_taubin_smoothing is not None:
    filter.UseTaubinSmoothing = use_taubin_smoothing
  if mu_factor is not None:
    filter.MuFactor = mu_factor
  filter.execute()
  return filter.ErrorCode

def quick_surface_mesh(data_container_array, selected_data_array_paths = None, surface_data_container_name = None, vertex_attribute_matrix_name = None, face_attribute_matrix_name = None, feature_ids_array_path = None, face_labels_array_name = None, node_types_array_name = None, feature_attribute_matrix_name = None, fix_problem_voxels = None, observer = None) -> int:
  """Pythonic interface to QuickSurfaceMesh Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    surface_data_container_name (DataArrayPath): Sets the "SurfaceDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    face_attribute_matrix_name (QString): Sets the "FaceAttributeMatrixName" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    face_labels_array_name (QString): Sets the "FaceLabelsArrayName" filter property
    node_types_array_name (QString): Sets the "NodeTypesArrayName" filter property
    feature_attribute_matrix_name (QString): Sets the "FeatureAttributeMatrixName" filter property
    fix_problem_voxels (bool): Sets the "FixProblemVoxels" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.QuickSurfaceMesh()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  if surface_data_container_name is not None:
    filter.SurfaceDataContainerName = surface_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if face_attribute_matrix_name is not None:
    filter.FaceAttributeMatrixName = face_attribute_matrix_name
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if face_labels_array_name is not None:
    filter.FaceLabelsArrayName = face_labels_array_name
  if node_types_array_name is not None:
    filter.NodeTypesArrayName = node_types_array_name
  if feature_attribute_matrix_name is not None:
    filter.FeatureAttributeMatrixName = feature_attribute_matrix_name
  if fix_problem_voxels is not None:
    filter.FixProblemVoxels = fix_problem_voxels
  filter.execute()
  return filter.ErrorCode

def reverse_triangle_winding(data_container_array, surface_data_container_name = None, observer = None) -> int:
  """Pythonic interface to ReverseTriangleWinding Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_data_container_name (DataArrayPath): Sets the "SurfaceDataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.ReverseTriangleWinding()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_data_container_name is not None:
    filter.SurfaceDataContainerName = surface_data_container_name
  filter.execute()
  return filter.ErrorCode

def shared_feature_face_filter(data_container_array, face_feature_attribute_matrix_name = None, surface_mesh_feature_face_ids_array_name = None, surface_mesh_feature_face_labels_array_name = None, surface_mesh_feature_face_num_triangles_array_name = None, surface_mesh_face_labels_array_path = None, observer = None) -> int:
  """Pythonic interface to SharedFeatureFaceFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    face_feature_attribute_matrix_name (QString): Sets the "FaceFeatureAttributeMatrixName" filter property
    surface_mesh_feature_face_ids_array_name (QString): Sets the "SurfaceMeshFeatureFaceIdsArrayName" filter property
    surface_mesh_feature_face_labels_array_name (QString): Sets the "SurfaceMeshFeatureFaceLabelsArrayName" filter property
    surface_mesh_feature_face_num_triangles_array_name (QString): Sets the "SurfaceMeshFeatureFaceNumTrianglesArrayName" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.SharedFeatureFaceFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if face_feature_attribute_matrix_name is not None:
    filter.FaceFeatureAttributeMatrixName = face_feature_attribute_matrix_name
  if surface_mesh_feature_face_ids_array_name is not None:
    filter.SurfaceMeshFeatureFaceIdsArrayName = surface_mesh_feature_face_ids_array_name
  if surface_mesh_feature_face_labels_array_name is not None:
    filter.SurfaceMeshFeatureFaceLabelsArrayName = surface_mesh_feature_face_labels_array_name
  if surface_mesh_feature_face_num_triangles_array_name is not None:
    filter.SurfaceMeshFeatureFaceNumTrianglesArrayName = surface_mesh_feature_face_num_triangles_array_name
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  filter.execute()
  return filter.ErrorCode

def triangle_area_filter(data_container_array, surface_mesh_triangle_areas_array_path = None, observer = None) -> int:
  """Pythonic interface to TriangleAreaFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_triangle_areas_array_path (DataArrayPath): Sets the "SurfaceMeshTriangleAreasArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.TriangleAreaFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_triangle_areas_array_path is not None:
    filter.SurfaceMeshTriangleAreasArrayPath = surface_mesh_triangle_areas_array_path
  filter.execute()
  return filter.ErrorCode

def triangle_centroid_filter(data_container_array, surface_mesh_triangle_centroids_array_path = None, observer = None) -> int:
  """Pythonic interface to TriangleCentroidFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_triangle_centroids_array_path (DataArrayPath): Sets the "SurfaceMeshTriangleCentroidsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.TriangleCentroidFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_triangle_centroids_array_path is not None:
    filter.SurfaceMeshTriangleCentroidsArrayPath = surface_mesh_triangle_centroids_array_path
  filter.execute()
  return filter.ErrorCode

def triangle_dihedral_angle_filter(data_container_array, surface_mesh_triangle_dihedral_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to TriangleDihedralAngleFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_triangle_dihedral_angles_array_path (DataArrayPath): Sets the "SurfaceMeshTriangleDihedralAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.TriangleDihedralAngleFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_triangle_dihedral_angles_array_path is not None:
    filter.SurfaceMeshTriangleDihedralAnglesArrayPath = surface_mesh_triangle_dihedral_angles_array_path
  filter.execute()
  return filter.ErrorCode

def triangle_normal_filter(data_container_array, surface_mesh_triangle_normals_array_path = None, observer = None) -> int:
  """Pythonic interface to TriangleNormalFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_triangle_normals_array_path (DataArrayPath): Sets the "SurfaceMeshTriangleNormalsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.TriangleNormalFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_triangle_normals_array_path is not None:
    filter.SurfaceMeshTriangleNormalsArrayPath = surface_mesh_triangle_normals_array_path
  filter.execute()
  return filter.ErrorCode

def generate_geometry_connectivity(data_container_array, surface_data_container_name = None, generate_vertex_triangle_lists = None, generate_triangle_neighbors = None, observer = None) -> int:
  """Pythonic interface to GenerateGeometryConnectivity Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_data_container_name (DataArrayPath): Sets the "SurfaceDataContainerName" filter property
    generate_vertex_triangle_lists (bool): Sets the "GenerateVertexTriangleLists" filter property
    generate_triangle_neighbors (bool): Sets the "GenerateTriangleNeighbors" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.GenerateGeometryConnectivity()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_data_container_name is not None:
    filter.SurfaceDataContainerName = surface_data_container_name
  if generate_vertex_triangle_lists is not None:
    filter.GenerateVertexTriangleLists = generate_vertex_triangle_lists
  if generate_triangle_neighbors is not None:
    filter.GenerateTriangleNeighbors = generate_triangle_neighbors
  filter.execute()
  return filter.ErrorCode

def rigid_point_cloud_transform(data_container_array, moving_geometry = None, moving_key_points = None, fixed_key_points = None, observer = None) -> int:
  """Pythonic interface to RigidPointCloudTransform Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    moving_geometry (DataArrayPath): Sets the "MovingGeometry" filter property
    moving_key_points (DynamicTableData): Sets the "MovingKeyPoints" filter property
    fixed_key_points (DynamicTableData): Sets the "FixedKeyPoints" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = surfacemeshing.RigidPointCloudTransform()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moving_geometry is not None:
    filter.MovingGeometry = moving_geometry
  if moving_key_points is not None:
    filter.MovingKeyPoints = moving_key_points
  if fixed_key_points is not None:
    filter.FixedKeyPoints = fixed_key_points
  filter.execute()
  return filter.ErrorCode

